# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [Unreleased]
## [0.5] - 2025-09-26
### Added
- `SECURITY.md`
### Changed
- Logo updated
- Python typing features added to all modules
- `det` function renamed to `calculate_determinant`
- `line` function renamed to `print_line`
- `description` function renamed to `print_description`
- `left_justify` function renamed to `justify_left`
- `justify` function renamed to `justify_text`
- `seq_generator` function renamed to `generate_sequence`
- `C_calc` function renamed to `calculate_C`
- `prob_calc` function renamed to `calculate_probability`
- `print_prob` function renamed to `print_probability`
- `game` function renamed to `run_game`
- `check_seq` function renamed to `validate_sequence`
- `get_seq` function renamed to `get_sequences`
- `get_len` function renamed to `get_length`
- `check_name` function renamed to `validate_name`
- `print_seq` function renamed to `print_sequence`
- `computer_seq_gen` function renamed to `generate_computer_sequence`
- `player_filter` function renamed to `filter_players`
- `menu` function renamed to `menu_handler`
- `print_probability` function bug fixed
- `get_names` function bug fixed
- Test system modified
- Build script updated
- CLI mode updated
- `Notebook.ipynb` updated
- `codecov` removed from `dev-requirements.txt`
- `Python 3.5` support dropped
- `Python 3.6` support dropped
- `Python 3.10` added to `test.yml`
- `Python 3.11` added to `test.yml`
- `Python 3.12` added to `test.yml`
- `Python 3.13` added to `test.yml`
- `README.md` modified
- String templates modified
## [0.4] - 2021-05-19
### Added
- `requirements-splitter.py`
- `print_seq` function
### Changed
- Test system modified
- `game` function modified
- Menu optimized
## [0.3] - 2020-04-16
### Changed
- `README.md` modified
- Minor issues fixed
- `print_result` function tie condition bug fixed
## [0.2] - 2020-04-08
### Added
- `det` function
- `prob_calc` function
- `print_prob` function
- `C_calc` function
- `Notebook.ipynb` file
- `build_unix.sh` file
- Github action
### Changed
- `README.md` modified
- `version_check.py` updated
## [0.1] - 2020-03-21
### Added
- Player mode
- Computer mode
- Exe version
- Test system

[Unreleased]: https://github.com/sepandhaghighi/penney/compare/v0.5...dev
[0.5]: https://github.com/sepandhaghighi/penney/compare/v0.4...v0.5
[0.4]: https://github.com/sepandhaghighi/penney/compare/v0.3...v0.4
[0.3]: https://github.com/sepandhaghighi/penney/compare/v0.2...v0.3
[0.2]: https://github.com/sepandhaghighi/penney/compare/v0.1...v0.2
[0.1]: https://github.com/sepandhaghighi/penney/compare/9c95239...v0.1



